BottomBarDetails class

Constructors

BottomBarDetails({required List<BottomBarItem?> items, required List<Item> circleItems, List<Color>? circleColors, IconThemeData? activeIconTheme, IconThemeData? iconTheme, TextStyle? activeTitleStyle, TextStyle? titleStyle})

Properties

activeIconTheme ↔ IconThemeData?
getter/setter pair
activeTitleStyle ↔ TextStyle?
getter/setter pair
circleColors ↔ List<Color>?
getter/setter pair
circleItems ↔ List<Item>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconTheme ↔ IconThemeData?
getter/setter pair
items ↔ List<BottomBarItem?>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleStyle ↔ TextStyle?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited