MenuNavScaffold class

Inheritance

Constructors

const

Properties

activefloatingIcon → Widget?
floating wodget when circular widget is hidden
final
appBar → PreferredSizeWidget?
final
backgroundColor → Color?
final
body → Widget?
final
bottomBarColor → Color?
final
bottomBarDetails → BottomBarDetails
bottombar details
final
bottomSheet → Widget?
final
cancelMenuFloatingIcon → Widget?
cancel circular widget
final
drawer → Widget?
final
drawerDragStartBehavior → DragStartBehavior
final
drawerEdgeDragWidth → double?
final
drawerEnableOpenDragGesture → bool
final
drawerScrimColor → Color?
final
endDrawer → Widget?
final
endDrawerEnableOpenDragGesture → bool
final
extendBodyBehindAppBar → bool
final
floatingButtonColor → Color?
floating button color
final
floatingbuttonsize → double
floating button size
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
navigation bar height
final
notchMargin → double
notch margin
final
onDrawerChanged → DrawerCallback?
final
onEndDrawerChanged → DrawerCallback?
final
persistentFooterButtons → List<Widget>?
final
primary → bool
final
resizeToAvoidBottomInset → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeColor → Color?
circular ring color
final
strokewidth → double?
ring width
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _MenuNavScaffoldState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited