CustomNavBar class

Inheritance

Constructors

CustomNavBar({Key? key, Color? color, double? elevation = 4.0, NotchedShape? shape, Clip clipBehavior = Clip.none, double notchMargin = 4.0, double? storkeWidth, required double floatingbuttonsize, double height = 60.0, required BottomBarDetails expandableBottomBarDetails, required bool shouldOpen, required VoidCallback onTapMenuButton, Color? floatingButtonColor, Color? strokeColor, Widget? activefloatingIcon, Widget? cancelMenuFloatingIcon, Duration forwardDuration = const Duration(milliseconds: 500), Duration reverseDuration = const Duration(milliseconds: 400)})
const

Properties

activefloatingIcon → Widget?
active floating widget
final
cancelMenuFloatingIcon → Widget?
final
clipBehavior → Clip
final
color → Color?
final
elevation → double?
final
expandableBottomBarDetails → BottomBarDetails
final
floatingButtonColor → Color?
final
floatingbuttonsize → double
final
forwardDuration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
notchMargin → double
final
onTapMenuButton → VoidCallback
final
reverseDuration → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → NotchedShape?
final
shouldOpen → bool
final
storkeWidth → double?
final
strokeColor → Color?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited